"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.boot = exports.register = exports.api = exports.name = void 0;
require("./interface");
const bud_build_1 = require("@roots/bud-build");
const Config_1 = require("./Config");
const fs_extra_1 = require("fs-extra");
const babel = {
    name: '@roots/bud-babel',
    api: (app) => ({
        babel: new Config_1.Config().init(app),
    }),
    register: ({ build, path }) => {
        fs_extra_1.ensureDirSync(path('storage', 'cache/babel'));
        build.loaders.babel = new bud_build_1.Loader(require.resolve('babel-loader'));
        build.items.babel = new bud_build_1.Item({
            loader: ({ build }) => build.loaders.babel,
            options: ({ path, babel }) => ({
                cacheDirectory: path('storage', 'cache/babel'),
                root: path('src'),
                presets: Object.values(babel.presets),
                plugins: Object.values(babel.plugins),
            }),
        });
        build.rules.js.setUse(({ build }) => [build.items.babel]);
    },
    boot: app => {
        !fs_extra_1.existsSync(app.path('project', 'babel.config.js')) &&
            app.babel.setPresets(['@babel/preset-env']).setPlugins([
                [
                    '@babel/plugin-transform-runtime',
                    {
                        helpers: false,
                    },
                ],
                '@babel/plugin-proposal-object-rest-spread',
                '@babel/plugin-syntax-dynamic-import',
                '@babel/plugin-proposal-class-properties',
            ]);
    },
};
exports.default = babel;
exports.name = babel.name, exports.api = babel.api, exports.register = babel.register, exports.boot = babel.boot;
//# sourceMappingURL=index.js.map